.. _Keyring: https://pypi.python.org/pypi/keyring
.. _ipython-secrets: https://github.com/osteele/ipython-secrets
.. _Google Sheet document key: https://webapps.stackexchange.com/questions/74205/what-is-the-key-in-my-google-sheets-url
